@@ -176,7 +176,7 @@
                   proximity = as.double(proxmatrix),
                   nodes = as.integer(nodes),
                   nodexts = as.integer(nodexts),
-                  DUP=FALSE,
+               ##   DUP=FALSE,
                   PACKAGE = "RRF")[keepIndex]
             ## Apply bias correction if needed.
             yhat <- rep(NA, length(rn))
@@ -231,7 +231,7 @@
                  prox = as.integer(proximity),
                  proxmatrix = as.double(proxmatrix),
                  nodes = as.integer(nodes),
-                 DUP=FALSE,
+            ##     DUP=FALSE,
                  PACKAGE = "RRF")
         if (out.type > 1) {
             out.class.votes <- t(matrix(t1$countts, nrow = nclass, ncol = ntest))
